==> haskell-socks-0.5.6-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.6
id: socks-0.5.6-DlL3HcMrZTZAvqg8EMqLHK
key: socks-0.5.6-DlL3HcMrZTZAvqg8EMqLHK
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: f4cbee0f8ad8f323f069350c704b7e73
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/socks-0.5.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/socks-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/socks-0.5.6
hs-libraries: HSsocks-0.5.6-DlL3HcMrZTZAvqg8EMqLHK
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    network-2.7.0.1-H3G12S9UXc14r49NrCjVOb
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             network-2.7.0.1-H3G12S9UXc14r49NrCjVOb=29a1441cc5e4aeb97125018af3ab80ef
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.5.6-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.6
id: socks-0.5.6-IpObzMGTpDbEYKpGT1Kke8
key: socks-0.5.6-IpObzMGTpDbEYKpGT1Kke8
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: d334feb34dfb48ff0b377047cf1bc684
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/socks-0.5.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/socks-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/socks-0.5.6
hs-libraries: HSsocks-0.5.6-IpObzMGTpDbEYKpGT1Kke8
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
